<?php
session_start(); // Start the session

if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    // Redirect to login.php if the user is not logged in
    header('Location: login.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>IP Info</title>
    <!-- Google Font -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;700&display=swap" rel="stylesheet">
    <!-- Styles -->
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #1e1e2f;
            color: #ffffff;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;

            margin: 50px;
        }

        .container {
            background-color: #2a2a3d;
            padding: 20px;
            margin: 20px;
            margin-top: 20px;
            border-radius: 10px;
            box-shadow: 0px 4px 20px rgba(0, 0, 0, 0.5);
            max-width: 400px;
            text-align: center;
        }

        h1 {
            font-size: 24px;
            margin-bottom: 20px;
            color: #f2f2f2;
        }

        p {
            font-size: 16px;
            margin: 10px 0;
        }

        .bold {
            font-weight: 700;
        }

        .btn {
            background-color: #4e54c8;
            color: white;
            padding: 10px 20px;
            border-radius: 5px;
            text-decoration: none;
            font-size: 14px;
            margin-top: 20px;
            display: inline-block;
        }

        .btn:hover {
            background-color: #6a70f0;
        }

        .clickable-ip {
            color: #4e54c8;
            cursor: pointer;
            text-decoration: underline;
        }

        .ip-details {
            margin-top: 20px;
            display: none;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>IP and Device Information</h1>

        <?php
        if (isset($_GET['ip'])) {
            $ip = htmlspecialchars($_GET['ip']);
            $filename = '../datauser/users.json';

            // Load existing data from the JSON file
            if (file_exists($filename)) {
                $existing_data = json_decode(file_get_contents($filename), true);

                // Search for the IP in the existing data
                $ip_found = false;
                foreach ($existing_data as $entry) {
                    if ($entry['ip'] === $ip) { // Updated to check against the 'ip' field
                        $ip_found = true;

                        // Display IP details (clickable IP address)
                        echo "<p><span class='bold'>IP:</span> <span class='clickable-ip' id='ipAddress'>{$entry['ip']}</span></p>";
                        echo "<p><span class='bold'>Timestamp:</span> " . ($entry['timestamp'] ?? 'Not available') . "</p>";

                        // Display device details, showing "Not available" if the data is missing
                        echo "<h2>Device Details</h2>";
                        echo "<p><span class='bold'>Browser:</span> " . ($entry['device_details']['browser'] ?? 'Not available') . "</p>";
                        echo "<p><span class='bold'>Version:</span> " . ($entry['device_details']['version'] ?? 'Not available') . "</p>";
                        echo "<p><span class='bold'>Platform:</span> " . ($entry['device_details']['platform'] ?? 'Not available') . "</p>";
                        echo "<p><span class='bold'>User Agent:</span> " . ($entry['user_agent'] ?? 'Not available') . "</p>";
                        echo "<p><span class='bold'>Accept Language:</span> " . ($entry['accept_language'] ?? 'Not available') . "</p>";
                        echo "<p><span class='bold'>Referer:</span> " . ($entry['referer'] ?? 'Not available') . "</p>";
                        break; // Exit the loop as we found the IP
                    }
                }

                if (!$ip_found) {
                    echo "<p>No information found for IP: $ip</p>";
                }
            } else {
                echo "<p>Data file not found</p>";
            }
        } else {
            echo "<p>No IP address provided</p>";
        }
        ?>

        <!-- Container to hold IP-API details -->
        <div id="ipDetails" class="ip-details"></div>

        <a class="btn" href="#" onclick="window.close(); return false;">Close this</a>
    </div>

    <script>
        document.getElementById('ipAddress').addEventListener('click', function () {
            const ip = this.innerText; // Get the IP address text

            // Fetch details from IP-API
            fetch(`http://ip-api.com/json/${ip}`)
                .then(response => response.json())
                .then(data => {
                    if (data.status === "success") {
                        const detailsDiv = document.getElementById('ipDetails');
                        detailsDiv.innerHTML = `
                            <h3>IP Details from IP-API</h3>
                            <p><span class='bold'>ISP:</span> ${data.isp}</p>
                            <p><span class='bold'>Organization:</span> ${data.org}</p>
                            <p><span class='bold'>Country:</span> ${data.country} (${data.countryCode})</p>
                            <p><span class='bold'>Region:</span> ${data.regionName} (${data.region})</p>
                            <p><span class='bold'>City:</span> ${data.city}</p>
                            <p><span class='bold'>ZIP Code:</span> ${data.zip}</p>
                            <p><span class='bold'>Latitude:</span> ${data.lat}</p>
                            <p><span class='bold'>Longitude:</span> ${data.lon}</p>
                            <p><span class='bold'>Timezone:</span> ${data.timezone}</p>
                        `;
                        detailsDiv.style.display = 'block'; // Show the details
                    } else {
                        alert('Unable to fetch IP details');
                    }
                })
                .catch(error => {
                    console.error('Error fetching IP details:', error);
                    alert('Error fetching IP details');
                });
        });

        document.addEventListener('keydown', function (event) {
            if (event.key === 'x' || event.key === 'X') {
                window.close(); // Attempt to close the tab
            }
        });
    </script>
</body>
</html>
